import requests
from bs4 import BeautifulSoup

def get_element_from_facts(facts, category):
    for x in facts:
        if x[0] == category:
            return x[1] if x[1] else "N/A"

def fetch_all_properties():
    bgl_url = "https://www.bgl.de"
    base_url = bgl_url + "/vermietung"

    url_params = {
        "address": "",
        "property_type": 3,
        "nroom": "",
        "sqft_min": "",
        "sqft_max": "",
        "max_price": "",
        "type_aufzug": "LIKE",
        "type_balkon": "LIKE",
        "sortby": "a.price",
        "orderby": "asc"
    }

    url = f"{base_url}?{url_params}"

    headers = {
        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:135.0) Gecko/20100101 Firefox/135.0',
        'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
        'Accept-Encoding': 'gzip, deflate, sdch, br',
        'Accept-Language': 'de,en-US;q=0.7,en;q=0.3',
        'Connection': 'keep-alive',
        'Upgrade-Insecure-Requests': '1',
        'Cache-Control': 'max-age=0',
    }

    response = requests.request("GET", url, headers=headers)

    soup = BeautifulSoup(response.text, "html.parser")

    # get all divs with class "property-item z-0"

    bgl_page_properties = soup.find_all("div", {"class": "property-item z-0"})

    properties = []

    for prop in bgl_page_properties:
        # get a from prop with class "btn btn-primary details z-0 me-2 mb-2 stretched-link_" and only extract the href
        prop_url = prop.find("a", {"class": "btn btn-primary details z-0 me-2 mb-2 stretched-link_"})["href"]
        response = requests.request("GET", bgl_url + prop_url, headers=headers)
        prop_soup = BeautifulSoup(response.text, "html.parser")

        # get h3 with class adresse and extract the text
        prop_title = prop_soup.find("h3", {"class": "adresse"}).text.strip()

        # create a value entrie tuple list
        facts = []


        steckbrief = prop_soup.find("div", {"class": "infoblock px-3 pt-2"})
        # get all uls with class "facts"
        facts_ul = steckbrief.find_all("ul", {"class": "facts"})
        # first li in ul has the room count
        general_lis = facts_ul[0].find_all("li")

        for li in general_lis:
            value = li.find("strong").text.strip()
            category = li.find("span").text.strip()
            facts.append((category, value))

        # get elements from facts that has the category "Zimmer"
        room_count = get_element_from_facts(facts, "Zimmer")
        size =  get_element_from_facts(facts, "Wohnfläche")
        level = get_element_from_facts(facts, "Etage")
        obj_id = get_element_from_facts(facts, "Objektnummer")
        availability = get_element_from_facts(facts, "verfügbar ab")

        money_li = facts_ul[1].find_all("li")

        for li in money_li:
            value = li.find("strong").text.strip()
            category = li.find("span").text.strip()
            facts.append((category, value))

        cold_rent = get_element_from_facts(facts, "Kaltmiete")
        other_costs = get_element_from_facts(facts, "Nebenkosten")
        heating_costs = get_element_from_facts(facts, "inkl. Heizkosten")
        rent = get_element_from_facts(facts, "Miete inkl. Nebenkosten")

        # image is in img tag with class "img-responsive"
        image_url = prop_soup.find("img", {"class": "img-responsive"})["src"]

        properties.append({
            "id": obj_id,
            "title": "BGL - " + prop_title,
            "subtitle": "",
            "rooms": room_count,
            "size": size,
            "rent": cold_rent,
            "link": bgl_url + prop_url,
            "abstract": "",
            "warm_rent": rent,
            "availability": availability,
            "image_url": image_url,
            "owner": "BGL",
        })

    return properties