import requests
from bs4 import BeautifulSoup

WOGETRA_URL = "https://www.wogetra.de/immobilien-vermarktungsart/miete/"

# Funktion: Scrape von Wogetra
def scrape_wogetra():
    response = requests.get(WOGETRA_URL)
    soup = BeautifulSoup(response.content, 'html.parser')

    # Find all property containers
    property_elements = soup.find_all("div", class_="property-container")
    properties = []

    for prop in property_elements:
        # Extract property details
        title_element = prop.find("h3", class_="property-title")
        subtitle_element = prop.find("div", class_="property-subtitle")
        link_element = title_element.find("a") if title_element else None

        details = prop.find("div", class_="property-data")

        # Extract details (ID, rooms, size, etc.)
        property_id = prop.get("id", "")
        title = title_element.text.strip() if title_element else "No Title"
        subtitle = subtitle_element.text.strip() if subtitle_element else "No Subtitle"
        link = link_element["href"] if link_element else "#"

        rooms = details.find("div", class_="data-anzahl_zimmer").find("div", class_="dd").text.strip() if details else "N/A"
        size = details.find("div", class_="data-wohnflaeche").find("div", class_="dd").text.strip() if details else "N/A"
        rent = details.find("div", class_="data-nettokaltmiete").find("div", class_="dd").text.strip() if details else "N/A"
        warm_rent = details.find("div", class_="data-warmmiete").find("div", class_="dd").text.strip() if details else "N/A"
        availability = details.find("div", class_="data-verfuegbar_ab").find("div", class_="dd").text.strip() if details else "N/A"

        # Add property to list
        properties.append({
            "id": property_id,
            "title": "Wogetra - "+ title,
            "subtitle": subtitle,
            "rooms": rooms,
            "size": size,
            "rent": rent,
            "link": link,
            "abstract": "",
            "warm_rent": warm_rent,
            "availability": availability,
            "image_url": "",
        })

    return properties